<a href="https://pypi.python.org/pypi/SOAPy-st/">
    <img src="https://img.shields.io/pypi/v/SOAPy-st.svg" alt="PyPI Version">
</a>
<a href="https://pepy.tech/project/SOAPy-st">
<img src="https://static.pepy.tech/personalized-badge/SOAPy-st?period=total&units=international_system&left_color=grey&right_color=orange&left_text=Downloads"
alt="PyPI downloads">
</a>
<a href='https://soapy-st.readthedocs.io/en/latest/?badge=latest'>
    <img src='https://readthedocs.org/projects/soapy-st/badge/?version=latest' alt='Documentation Status' />
</a>

# SOAPy: A package for **S**patial-**O**mics **A**nalysis in **Py**thon

<div align=left><img width = '200' height ='80' src ="logo_soapy.png"/></div>

## Brief Introduction
**SOAPy** is an integrated toolkit that focuses on addressing spatial heterogeneity. SOAPy contains four data
preprocessing modules (“Data Import”, “spatial network”, and “Spatial Domain”), three modules for analyzing spatial
expression patterns of genes (“Spatial Variation”, “Spatial Tendency”, and “Spatiotemporal Pattern”), two modules
for analyzing the spatial architecture of cells (“Spatial Proximity”, “Spatial Composition”), and two module for
analyzing Spatial Communication.

## Pipeline

<div align=center><img width = '948' height ='800' src ="pipeline.png"/></div>

## Installation
pip:
```
    pip install SOAPy-st
```
github:
```
    cd SOAPy-st
    python setup.py build
    python setup.py install
```
